@@ -60,7 +60,7 @@ def show(obj: Dict, id: Optional[int], external_id: Optional[str], job_id: Optio
             click.echo("Job details:")
             click.echo(print_jobs([job]))
             click.echo("SQL Query:")
-            click.echo(print_sql(job.raw_query))
+            click.echo(print_sql(job.query))
             if job.status == "Failed":
                 click.echo(f"Error Details: {job.error}")
             if metrics:
